netapp_ontap.models.ldap_ip_status API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ldap_ip_status`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class LdapIpStatusSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the LdapIpStatus object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `code: Size GET POST PATCH`

    Code corresponding to the error message. If there is no error, it is 0 to indicate success.

    Example: 65537300

  `dn_messages: List[str] GET POST PATCH`

    The dn_messages field of the ldap_ip_status.

  `message: str GET POST PATCH`

    Provides additional details on the error.

  `state: str GET POST PATCH`

    Status of the LDAP service.

    Valid choices:

    - up
    - down